==> bizext.php5.3_5.6.zip: bizext/lib/spout/Common/Exception/SpoutException.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPxFeqyApC2Zrybn6uJ7vsYtXs+qtnt1KgCWF3BDDfpYspXDJoFpPQRqUxNhB/y/OLzeBd8kx
ZBj4SLu8/VeB+QyqT2KUEF94GvxibDz3sZrDLAvHI1tX4mWd4yIYCP4RKyg60qx9lYddXHgbCUN+
xCRAhZ0+P4Xs8a8QCu8L4A+0Bci2zLtzC0KnrEOUJzo5Nzfo/YkAHRo/JTB8yp91A+JpJvovWe9r
CVSYWGOEs7WwcU5qovGYtophzLSZobio848T6uLViV4F+5oTrcA0p/FPz2dhYW1Qr8q4Llb0Bh1i
+skldA4d8k9nDkxtbtav4LaJpZThcTaKBg4Oa8LhOw5EWOJ9vRXgsKOiZhhlIq8q5UbwZFMggaS2
XiBb2f0WXhuQM+xsNEYlJn+fVLR6+/xlHfBArzKYAa9mawumMELoO5sbZX3ZLqO3jLfjrmeOHzN3
fh4N5ZxELRDYoAKdFPMGfNJYcKf5EW4aCQ3jHYGIQQVD/fkhSiNEueS4Gu0NKDoO/rM/ntR8EuDb
YrtihplXlB9z2viaazpAD39qRo0usyk2L0QNBPc0gssgo89GeVTibtDfvZYINjHdBn/9X2i1PO96
LIkt0+utMvkGzAyhNXI0w81dS/2AUPsHphsrAhRngRXBdjMa6tuBXKn/Wr5ZZU0+fwvZgIq=

==> bizext.php7.0.zip: bizext/lib/spout/Common/Exception/SpoutException.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPmqngiKG6I/gMOG/viJH1rwhYN6HQG7rDpAfh953TCCAAtG7RRLi9CBbQnAEgdneFjNqJYZ8
R8PuJ3dLfRmuvPF2r7BDwuuAK2o3oKJ7YtWZk4XhzZ7HcIpZekTCn8jixmaHwlAqJ1PC5YHPSyLa
3h3kP/3lezv+uu5YMvh9A8HRkA1NRYYQVcGoWwKQsf3omj3mr9Mopik/gOTQy3sKnb61pbz/q5jt
nwXZKTH96YP6cunby/RROOxMP+2y4GZXrjp3+wxx7f8UKMmzjQm/SJcD0gSVJpsf/M7Y7NWczBqC
lM8px/Sq1iUG3s7uGNUDsaZQ7f/218ICwaRqPuM4AGe6x2tPAFEx5Wr2ux2MvAq5PPgIgKrJiHu1
I1AOX58QWdimFnaA1WVxqPD7JZ5rhXQpdICy0no12ZV/PVHgaoe5ZpvmhJ90wDg6vIQX+J4qsvQN
kZBiigcu8tySlne6tWmhThWwIdQIDAsO4oEnsH4JZP9dnCNiWPnTQaJmO87prYf8GIC00aajl+qi
uJtKkAWDs1uSUzwu9VsRsp9qbiS8ibg+DQxT7619TcSE44W2LImxvcddxgt062biQsc8woP9sT9k
a4A3IUIBtkfI8vZAPxCYKgAzeWThMmxXin0NmTl0iWr6tzHhJGdnhfkBN/LTBs9WJqgDWQa3o21P
MIXQibs2JnjF3kzdGPtqhol1K8zRT+lEFoRTBlH0GAeSqLAND7YzGgtt09KtYKp2RNOH6VXu0FEz
kzxG79NI8ty8vnD3P/5LSbdxnr4h2DTEwCZ/AV/5hU3ZfkMOPrOEt/dLrSTx4kI4wwPlrZrOTxl6
TIkood5DDjbyLPSCWUzXSpLoWWTCJrhnaoUY1JCfEDlPiNyZyU3BGC8NLdXaQexGU/PFQ2rICQCx
H1NGvv0TEKcOCV1UHvk/P7z5jJfzyq7/5DLE/xc8Mj0IjrF5+XSHxvnK4mlGw/8rQS3uT26qSAvI
qCK1
